@@ -999,7 +999,7 @@ def Robust_Ranking(df,
                                                  temp_columns_list,
                                                  perturbed_weights)
             temp_df = temp_df.nlargest(top_values, columns = 'Weighted Score (Sum)')
-            temp_list = temp_df[index_column].values.tolist()
+            temp_list = temp_df.index.values.tolist()
             alter_list.append(temp_list)
             
         elif score_type == 'weighted_product':
@@ -1009,7 +1009,7 @@ def Robust_Ranking(df,
                                                  temp_columns_list,
                                                  perturbed_weights)
             temp_df = temp_df.nlargest(top_values, columns = 'Weighted Score (Product)')
-            temp_list = temp_df[index_column].values.tolist()
+            temp_list = temp_df.index.values.tolist()
             alter_list.append(temp_list)
             
         elif score_type == 'topsis':
@@ -1019,13 +1019,13 @@ def Robust_Ranking(df,
                                            temp_columns_list,
                                            perturbed_weights)
             temp_df = temp_df.nlargest(top_values, columns = 'TOPSIS Score')
-            temp_list = temp_df[index_column].values.tolist()
+            temp_list = temp_df.index.values.tolist()
             alter_list.append(temp_list)
            
     
     sum_counts = Counter(x for sublist in alter_list for x in sublist)
     sum_counts = pd.DataFrame.from_dict(sum_counts,orient='index').reset_index()
-    sum_counts = sum_counts.rename(columns={'index':index_column,0:count_column_name})
+    sum_counts = sum_counts.rename(columns={0:count_column_name})
     sum_counts.sort_values(by=count_column_name, ascending=False,inplace=True)
     sum_counts[proportion_column_name] = sum_counts[count_column_name]/(temp_perturbations)
     
@@ -1033,8 +1033,7 @@ def Robust_Ranking(df,
     if include_plot is True:
         fig, ax = plt.subplots(1,1,figsize = (8,5))
 
-        sum_counts.plot.bar(x=index_column,
-                            y=proportion_column_name,
+        sum_counts.plot.bar(y=proportion_column_name,
                             ax = ax,
                             color = 'blue',
                             alpha = 0.5,
