@@ -39,6 +39,9 @@ def radar_plot(df,plot_package='matplotlib',savefig=False,save_path='radar.png')
     fig          : the radar plot
 
     """
+    plt.rcParams['font.sans-serif'] = ['SimHei']
+    plt.rcParams['axes.unicode_minus'] = False
+    
     names = list(df.index)
     labels = list(df.columns)
     data = [dict(df.loc[names[i],:]) for i in range(len(names))]
@@ -62,7 +65,7 @@ def radar_plot(df,plot_package='matplotlib',savefig=False,save_path='radar.png')
     # 设置雷达图中每一项的标签显示
     ax.set_thetagrids(angles*180/np.pi, labels)
     plt.legend(names)
-    plt.show()
+    #plt.show()
     
     return fig
 
